==> ag.db_2.0.2.tar.gz: ag.db/man/agACCNUM.Rd <==
\name{agACCNUM}

\alias{agACCNUM}
\alias{agMULTIHIT}

\title{Map between manufacturer IDs and AGI locus IDs}

\description{ 
  \code{agACCNUM} and \code{agMULTIHIT} are R objects
  that provide mappings between manufacturer IDs and AGI locus IDs.
}

\details{
  Each manufacturer ID is mapped to a vector of AGI locus IDs.

  For \code{agACCNUM} and \code{agMULTIHIT}
  an \code{NA} is assigned to those manufacturer IDs that can not be
  mapped to an AGI locus ID at this time.

  In addition, for \code{agACCNUM}, the character string
  \code{"multiple"} is assigned to those manufacturer IDs that are
  mapped to more than one AGI locus ID.
  And for \code{agMULTIHIT}, an \code{NA} is also assigned
  to those manufacturer IDs that are mapped to a single AGI locus ID.

  Mappings were based on data provided by: Tair ( ftp://ftp.arabidopsis.org/Microarrays/Affymetrix/affy\_AG\_array\_elements-2007-5-2.txt ) on 2007-Aug2
}

\seealso{
  \code{\link[AnnotationDbi]{nhit}}
}

\examples{
  x <- agACCNUM
  y <- agMULTIHIT
  identical(keys(x), keys(y))    # TRUE

  nhx <- nhit(x)
  nhy <- nhit(y)
  identical(names(nhx), keys(x)) # TRUE
  identical(names(nhy), keys(y)) # TRUE
  table(nhx)
  table(nhy)

  onehit_probes <- names(nhx)[nhx != 0 & nhy == 0]
  x[[onehit_probes[1]]]          # a single AGI locus ID
  y[[onehit_probes[1]]]          # NA

  multihit_probes <- names(nhx)[nhy != 0]
  x[[multihit_probes[1]]]        # "multiple"
  y[[multihit_probes[1]]]        # several AGI locus IDs

  nohit_probes <- names(nhx)[nhx == 0]
  x[[nohit_probes[1]]]           # NA
  y[[nohit_probes[1]]]           # NA

  any(nhx == 0 & nhy != 0)       # FALSE

  ## Back to a more "normal" map (that combines the data from 'x' and 'y')
  xy <- as(x, "AnnDbBimap")      # 'as(y, "AnnDbBimap")' works too
  xy[[onehit_probes[1]]]         # a single AGI locus ID
  xy[[multihit_probes[1]]]       # several AGI locus IDs
  xy[[nohit_probes[1]]]          # NA
}

\keyword{datasets}

==> ag.db_2.2.0.tar.gz: ag.db/man/agACCNUM.Rd <==
\name{agACCNUM}

\alias{agACCNUM}
\alias{agMULTIHIT}

\title{Map between manufacturer IDs and AGI locus IDs}

\description{ 
  \code{agACCNUM} and \code{agMULTIHIT} are R objects
  that provide mappings between manufacturer IDs and AGI locus IDs.
}

\details{
  Each manufacturer ID is mapped to a vector of AGI locus IDs.

  For \code{agACCNUM} and \code{agMULTIHIT}
  an \code{NA} is assigned to those manufacturer IDs that can not be
  mapped to an AGI locus ID at this time.

  In addition, for \code{agACCNUM}, the character string
  \code{"multiple"} is assigned to those manufacturer IDs that are
  mapped to more than one AGI locus ID.
  And for \code{agMULTIHIT}, an \code{NA} is also assigned
  to those manufacturer IDs that are mapped to a single AGI locus ID.

  Mappings were based on data provided by: Tair ( ftp://ftp.arabidopsis.org/Microarrays/Affymetrix/affy\_AG\_array\_elements-2007-5-2.txt ) on 2007-Oct04
}

\seealso{
  \code{\link[AnnotationDbi]{nhit}}
}

\examples{
  x <- agACCNUM
  y <- agMULTIHIT
  identical(keys(x), keys(y))    # TRUE

  nhx <- nhit(x)
  nhy <- nhit(y)
  identical(names(nhx), keys(x)) # TRUE
  identical(names(nhy), keys(y)) # TRUE
  table(nhx)
  table(nhy)

  onehit_probes <- names(nhx)[nhx != 0 & nhy == 0]
  x[[onehit_probes[1]]]          # a single AGI locus ID
  y[[onehit_probes[1]]]          # NA

  multihit_probes <- names(nhx)[nhy != 0]
  x[[multihit_probes[1]]]        # "multiple"
  y[[multihit_probes[1]]]        # several AGI locus IDs

  nohit_probes <- names(nhx)[nhx == 0]
  x[[nohit_probes[1]]]           # NA
  y[[nohit_probes[1]]]           # NA

  any(nhx == 0 & nhy != 0)       # FALSE

  ## Back to a more "normal" map (that combines the data from 'x' and 'y')
  xy <- as(x, "AnnDbBimap")      # 'as(y, "AnnDbBimap")' works too
  xy[[onehit_probes[1]]]         # a single AGI locus ID
  xy[[multihit_probes[1]]]       # several AGI locus IDs
  xy[[nohit_probes[1]]]          # NA
}

\keyword{datasets}
